@@ -146,9 +146,11 @@ namespace citygml {
         NODETYPE( GML, Shell )
         NODETYPE( GML, PolyhedralSurface )
         NODETYPE( GML, Surface )
-        NODETYPE( GML, PolygonPatch)
+        NODETYPE( GML, PolygonPatch )
 
         NODETYPE( GML, LineString )
+        
+        NODETYPE( GML, RectifiedGridCoverage )
 
         // BLDG
         NODETYPE( BLDG, Building )
@@ -209,7 +211,8 @@ namespace citygml {
         NODETYPE( BLDG, OuterCeilingSurface )
         NODETYPE( BLDG, OuterFloorSurface )
         NODETYPE( BLDG, BuildingFurniture )
-
+        NODETYPE( BLDG, IntBuildingInstallation)
+            
         NODETYPE( BLDG, CityFurniture )
         NODETYPE( BLDG, Address)
 
