@@ -15,6 +15,7 @@
 #include <citygml/citymodel.h>
 #include <citygml/implictgeometry.h>
 #include <citygml/citygmllogger.h>
+#include <citygml/rectifiedgridcoverage.h>
 
 namespace citygml {
 
@@ -26,6 +27,10 @@ namespace citygml {
         m_logger = logger;
     }
 
+    RectifiedGridCoverage* CityGMLFactory::createRectifiedGridCoverage(std::string const& id) {
+        return new RectifiedGridCoverage(id);
+    }
+
     CityModel* CityGMLFactory::createCityModel(const std::string& id)
     {
         return new CityModel(id);
@@ -58,15 +63,17 @@ namespace citygml {
             return Geometry::GeometryType::GT_OuterCeiling;
         case CityObject::CityObjectsType::COT_OuterFloorSurface:
             return Geometry::GeometryType::GT_OuterFloor;
+        case CityObject::CityObjectsType::COT_TINRelief:
+            return Geometry::GeometryType::GT_Tin;
         default:
             return Geometry::GeometryType::GT_Unknown;
         }
 
     }
 
-    Geometry* CityGMLFactory::createGeometry(const std::string& id, const CityObject::CityObjectsType& cityObjType, unsigned int lod)
+    Geometry* CityGMLFactory::createGeometry(const std::string& id, const CityObject::CityObjectsType& cityObjType, unsigned int lod, std::string srsName)
     {
-        Geometry* geom = new Geometry(id, mapCityObjectsTypeToGeometryType(cityObjType), lod);
+        Geometry* geom = new Geometry(id, mapCityObjectsTypeToGeometryType(cityObjType), lod, srsName);
         appearanceTargetCreated(geom);
         return geom;
     }
@@ -86,7 +93,11 @@ namespace citygml {
     {
         LineString* lineString = new LineString(id);
         return std::shared_ptr<LineString>(lineString);
+    }
 
+    ExternalReference* CityGMLFactory::createExternalReference(const std::string& id)
+    {
+        return new ExternalReference(id);
     }
 
     void CityGMLFactory::requestSharedPolygonForGeometry(Geometry* geom, const std::string& polygonId)
