@@ -231,7 +231,7 @@ namespace citygml {
         }
     }
 
-    void Polygon::finish(Tesselator& tesselator, bool optimize, std::shared_ptr<CityGMLLogger> logger)
+    void Polygon::finish(Tesselator& tesselator, bool optimize, bool tesselate, std::shared_ptr<CityGMLLogger> logger)
     {
         if (m_finished) {
             // This may happen as Polygons can be shared between geometries
@@ -243,9 +243,10 @@ namespace citygml {
         if (optimize) {
             removeDuplicateVerticesInRings(logger);
         }
-
-        computeIndices(tesselator, logger);
-
+        
+        if (tesselate) {
+            computeIndices(tesselator, logger);
+        }
     }
 
     void Polygon::addRing( LinearRing* ring )
