@@ -10,6 +10,8 @@
 #include "parser/delayedchoiceelementparser.h"
 #include "parser/linestringelementparser.h"
 #include "parser/addressparser.h"
+#include "parser/rectifiedgridcoverageparser.h"
+#include "parser/externalreferenceparser.h"
 
 #include <citygml/citygmlfactory.h>
 #include <citygml/citygmllogger.h>
@@ -93,6 +95,12 @@ namespace citygml {
                 typeIDTypeMap.insert(HANDLE_TYPE(BLDG, OuterFloorSurface));
                 typeIDTypeMap.insert(HANDLE_TYPE(GRP, CityObjectGroup));
                 typeIDTypeMap.insert(HANDLE_TYPE(DEM, ReliefFeature));
+                typeIDTypeMap.insert(HANDLE_TYPE(DEM, ReliefComponent));
+                typeIDTypeMap.insert(HANDLE_TYPE(DEM, TINRelief));
+                typeIDTypeMap.insert(HANDLE_TYPE(DEM, MassPointRelief));
+                typeIDTypeMap.insert(HANDLE_TYPE(DEM, BreaklineRelief));
+                typeIDTypeMap.insert(HANDLE_TYPE(DEM, RasterRelief));
+                typeIDTypeMap.insert(HANDLE_TYPE(BLDG, IntBuildingInstallation));
 
                 typeIDTypeMapInitialized = true;
             }
@@ -237,6 +245,12 @@ namespace citygml {
 
     bool CityObjectElementParser::parseElementEndTag(const NodeType::XMLNode&, const std::string&)
     {
+        if (getSourceSRSOverride()) {
+            Envelope *envelope = new Envelope(getEnvelope().srsName());
+            envelope->setLowerBound(m_model->getEnvelope().getLowerBound());
+            envelope->setUpperBound(m_model->getEnvelope().getUpperBound());
+            m_model->setEnvelope(envelope);
+        }
         m_callback(m_model);
         m_model = nullptr;
         return true;
@@ -261,6 +275,11 @@ namespace citygml {
         } else if (attributesSet.count(node.typeID()) > 0 || node == NodeType::GEN_ValueNode) {
 
             return true;
+        } else if (node == NodeType::GML_RectifiedGridCoverageNode) {
+            
+            setParserForNextElement(new RectifiedGridCoverageParser(m_documentParser, m_factory, m_logger, [this](RectifiedGridCoverage * rectifiedGridCoverage) {
+                m_model->setRectifiedGridCoverage(rectifiedGridCoverage);
+            }));
         } else if (node == NodeType::BLDG_BoundedByNode
                    || node == NodeType::BLDG_OuterBuildingInstallationNode
                    || node == NodeType::BLDG_InteriorBuildingInstallationNode
@@ -273,7 +292,14 @@ namespace citygml {
                    || node == NodeType::GRP_ParentNode
                    || node == NodeType::TRANS_TrafficAreaNode
                    || node == NodeType::TRANS_AuxiliaryTrafficAreaNode
-                   || node == NodeType::WTR_BoundedByNode) {
+                   || node == NodeType::WTR_BoundedByNode
+                   || node == NodeType::DEM_ReliefComponentNode
+                   || node == NodeType::DEM_TINReliefNode
+                   || node == NodeType::DEM_MassPointReliefNode
+                   || node == NodeType::DEM_BreaklineReliefNode
+                   || node == NodeType::DEM_RasterReliefNode
+                   || node == NodeType::DEM_GridNode
+                   || node == NodeType::CORE_GeneralizesToNode) {
             setParserForNextElement(new CityObjectElementParser(m_documentParser, m_factory, m_logger, [this](CityObject* obj) {
                                         m_model->addChildCityObject(obj);
                                     }));
@@ -281,6 +307,18 @@ namespace citygml {
                    || node == NodeType::APP_AppearanceMemberNode) {
 
             setParserForNextElement(new AppearanceElementParser(m_documentParser, m_factory, m_logger));
+        } else if (node == NodeType::DEM_ExtentNode
+                   || node == NodeType::DEM_TinNode
+                   || node == NodeType::DEM_ReliefPointsNode
+                   || node == NodeType::DEM_RidgeOrValleyLinesNode
+                   || node == NodeType::DEM_BreaklinesNode) {
+            
+            parseGeometryForLODLevel(std::stoi(m_model->getAttribute("dem:lod")));
+        } else if (node == NodeType::GEN_Lod0TerrainIntersectionNode
+                   || node == NodeType::WTR_Lod0MultiCurveNode
+                   || node == NodeType::WTR_Lod0MultiSurfaceNode) {
+            
+            parseGeometryForLODLevel(0);
         } else if (node == NodeType::BLDG_Lod1MultiCurveNode
                    || node == NodeType::BLDG_Lod1MultiSurfaceNode
                    || node == NodeType::BLDG_Lod1SolidNode
@@ -330,7 +368,10 @@ namespace citygml {
                    || node == NodeType::WTR_Lod4SurfaceNode) {
 
             parseGeometryForLODLevel(4);
-        } else if (node == NodeType::GEN_Lod1GeometryNode
+        } else if (node == NodeType::GEN_Lod0GeometryNode) {
+            parseGeometryPropertyElementForLODLevel(0, attributes.getCityGMLIDAttribute());
+        }
+        else if (node == NodeType::GEN_Lod1GeometryNode
                    || node == NodeType::FRN_Lod1GeometryNode
                    || node == NodeType::VEG_Lod1GeometryNode) {
             parseGeometryPropertyElementForLODLevel(1, attributes.getCityGMLIDAttribute());
@@ -349,6 +390,9 @@ namespace citygml {
                    || node == NodeType::BLDG_Lod4GeometryNode
                    || node == NodeType::VEG_Lod4GeometryNode) {
             parseGeometryPropertyElementForLODLevel(4, attributes.getCityGMLIDAttribute());
+        } else if (node == NodeType::GEN_Lod0ImplicitRepresentationNode) {
+          
+            parseImplicitGeometryForLODLevel(0);
         } else if (node == NodeType::VEG_Lod1ImplicitRepresentationNode
                    || node == NodeType::FRN_Lod1ImplicitRepresentationNode
                    || node == NodeType::GEN_Lod1ImplicitRepresentationNode) {
@@ -369,17 +413,14 @@ namespace citygml {
                    || node == NodeType::GEN_Lod4ImplicitRepresentationNode) {
 
             parseImplicitGeometryForLODLevel(4);
-        } else if (node == NodeType::CORE_GeneralizesToNode
-                   || node == NodeType::CORE_ExternalReferenceNode
-                   || node == NodeType::GML_MultiPointNode
+        } else if (node == NodeType::CORE_ExternalReferenceNode){
+            
+            setParserForNextElement(new ExternalReferenceParser(m_documentParser, m_factory, m_logger, [this](ExternalReference * externalReference){
+                m_model->setExternalReference(externalReference);
+            }));
+        } else if (node == NodeType::GML_MultiPointNode
                    || node == NodeType::GRP_GeometryNode
-                   || node == NodeType::DEM_ReliefComponentNode
-                   || node == NodeType::GEN_Lod0GeometryNode
-                   || node == NodeType::GEN_Lod0ImplicitRepresentationNode
-                   || node == NodeType::GEN_Lod0TerrainIntersectionNode
-                   || node == NodeType::TRANS_Lod0NetworkNode
-                   || node == NodeType::WTR_Lod0MultiCurveNode
-                   || node == NodeType::WTR_Lod0MultiSurfaceNode) {
+                   || node == NodeType::TRANS_Lod0NetworkNode) {
             CITYGML_LOG_INFO(m_logger, "Skipping CityObject child element <" << node  << ">  at " << getDocumentLocation() << " (Currently not supported!)");
             setParserForNextElement(new SkipElementParser(m_documentParser, m_logger, node));
             return true;
@@ -497,6 +538,15 @@ namespace citygml {
                     || node == NodeType::LUSE_Lod3MultiSurfaceNode
                     || node == NodeType::LUSE_Lod4MultiSurfaceNode
                     || node == NodeType::DEM_ReliefComponentNode
+                    || node == NodeType::DEM_TINReliefNode
+                    || node == NodeType::DEM_MassPointReliefNode
+                    || node == NodeType::DEM_BreaklineReliefNode
+                    || node == NodeType::DEM_RasterReliefNode
+                    || node == NodeType::DEM_TinNode
+                    || node == NodeType::DEM_ReliefPointsNode
+                    || node == NodeType::DEM_RidgeOrValleyLinesNode
+                    || node == NodeType::DEM_BreaklinesNode
+                    || node == NodeType::DEM_GridNode
                     || node == NodeType::GEN_Lod0GeometryNode
                     || node == NodeType::GEN_Lod0ImplicitRepresentationNode
                     || node == NodeType::GEN_Lod0TerrainIntersectionNode
