@@ -267,6 +267,7 @@ namespace citygml {
                 INITIALIZE_NODE( BLDG, OuterFloorSurface )
                 INITIALIZE_NODE( BLDG, BuildingFurniture )
                 INITIALIZE_NODE( BLDG, RoofType)
+                INITIALIZE_NODE( BLDG, IntBuildingInstallation)
 
                 INITIALIZE_NODE( BLDG, CityFurniture )
 
@@ -586,9 +587,11 @@ namespace citygml {
     DEFINE_NODE( GML, Shell )
     DEFINE_NODE( GML, PolyhedralSurface )
     DEFINE_NODE( GML, Surface )
-    DEFINE_NODE( GML, PolygonPatch)
+    DEFINE_NODE( GML, PolygonPatch )
 
-    DEFINE_NODE( GML, LineString)
+    DEFINE_NODE( GML, LineString )
+
+    DEFINE_NODE( GML, RectifiedGridCoverage )
 
     // BLDG
     DEFINE_NODE( BLDG, Building )
@@ -646,7 +649,8 @@ namespace citygml {
     DEFINE_NODE( BLDG, OuterFloorSurface )
     DEFINE_NODE( BLDG, BuildingFurniture )
     DEFINE_NODE( BLDG, RoofType)
-
+    DEFINE_NODE( BLDG, IntBuildingInstallation)
+        
     DEFINE_NODE( BLDG, CityFurniture )
 
     DEFINE_NODE( BLDG, Address)
