@@ -32,12 +32,12 @@ void usage()
     std::cout << "  -filter <mask>  CityGML objects to parse (default:All)" << std::endl
         << "                  The mask is composed of:" << std::endl
         << "                   GenericCityObject, Building, Room," << std::endl
-        << "                   BuildingInstallation, BuildingFurniture, Door, Window, " << std::endl
+        << "                   BuildingInstallation, BuildingFurniture, IntBuildingInstallation, Door, Window, " << std::endl
         << "                   CityFurniture, Track, Road, Railway, Square, PlantCover," << std::endl
         << "                   SolitaryVegetationObject, WaterBody, TINRelief, LandUse," << std::endl
         << "                   Tunnel, Bridge, BridgeConstructionElement," << std::endl
         << "                   BridgeInstallation, BridgePart, All" << std::endl
-        << "                  and seperators |,&,~." << std::endl
+        << "                  and separators |,&,~." << std::endl
         << "                  Examples:" << std::endl
         << "                  \"All&~Track&~Room\" to parse everything but tracks & rooms" << std::endl
         << "                  \"Road&Railway\" to parse only roads & railways" << std::endl;
@@ -62,6 +62,7 @@ int main( int argc, char **argv )
         if ( param == "-log" ) { log = true; fargc = i+1; }
         //if ( param == "-filter" ) { if ( i == argc - 1 ) usage(); params.objectsMask = argv[i+1]; i++; fargc = i+1; }
         if ( param == "-destsrs" ) { if ( i == argc - 1 ) usage(); params.destSRS = argv[i+1]; i++; fargc = i+1; }
+        if ( param == "-srcsrs" ) { if ( i == argc - 1 ) usage(); params.srcSRS = argv[i+1]; i++; fargc = i+1; }
     }
 
     if ( argc - fargc < 1 ) usage();
